@@ -22,6 +22,10 @@ var (
 		metricPrefix+"system_info",
 		"Contains meta information about Nextcloud as labels. Value is always 1.",
 		[]string{"version"}, nil)
+	systemUpdateAvailableDesc = prometheus.NewDesc(
+		metricPrefix+"system_update_available",
+		"Contains information whether a system update is available (0 = no, 1 = yes). The available_version label contains the latest available nextcloud version, whereas the version label contains the current installed nextcloud version.",
+		[]string{"version", "available_version"}, nil)
 	appsInstalledDesc = prometheus.NewDesc(
 		metricPrefix+"apps_installed_total",
 		"Number of currently installed apps",
@@ -85,19 +89,21 @@ var (
 )
 
 type nextcloudCollector struct {
-	log         logrus.FieldLogger
-	infoClient  client.InfoClient
-	appsMetrics bool
+	log           logrus.FieldLogger
+	infoClient    client.InfoClient
+	appsMetrics   bool
+	updateMetrics bool
 
 	upMetric           prometheus.Gauge
 	scrapeErrorsMetric *prometheus.CounterVec
 }
 
-func RegisterCollector(log logrus.FieldLogger, infoClient client.InfoClient, appsMetrics bool) error {
+func RegisterCollector(log logrus.FieldLogger, infoClient client.InfoClient, appsMetrics bool, updateMetrics bool) error {
 	c := &nextcloudCollector{
-		log:         log,
-		infoClient:  infoClient,
-		appsMetrics: appsMetrics,
+		log:           log,
+		infoClient:    infoClient,
+		appsMetrics:   appsMetrics,
+		updateMetrics: updateMetrics,
 
 		upMetric: prometheus.NewGauge(prometheus.GaugeOpts{
 			Name: metricPrefix + "up",
@@ -151,14 +157,20 @@ func (c *nextcloudCollector) collectNextcloud(ch chan<- prometheus.Metric) error
 		return err
 	}
 
-	return readMetrics(ch, status, c.appsMetrics)
+	return readMetrics(ch, status, c.appsMetrics, c.updateMetrics)
 }
 
-func readMetrics(ch chan<- prometheus.Metric, status *serverinfo.ServerInfo, appsMetrics bool) error {
+func readMetrics(ch chan<- prometheus.Metric, status *serverinfo.ServerInfo, appsMetrics bool, updateMetrics bool) error {
 	if err := collectSimpleMetrics(ch, status, appsMetrics); err != nil {
 		return err
 	}
 
+	if updateMetrics {
+		if err := collectUpdate(ch, status); err != nil {
+			return err
+		}
+	}
+
 	if err := collectShares(ch, status.Data.Nextcloud.Shares); err != nil {
 		return err
 	}
@@ -261,6 +273,24 @@ func collectSimpleMetrics(ch chan<- prometheus.Metric, status *serverinfo.Server
 	return nil
 }
 
+func collectUpdate(ch chan<- prometheus.Metric, status *serverinfo.ServerInfo) error {
+	systemInfo := status.Data.Nextcloud.System
+	updateAvailableValue := 0.0
+
+	// Fix small bug: its indicated as "true" even if there is no real update available.
+	if systemInfo.Update.Available && systemInfo.Version != systemInfo.Update.AvailableVersion {
+		updateAvailableValue = 1.0
+	}
+
+	metric, err := prometheus.NewConstMetric(systemUpdateAvailableDesc, prometheus.GaugeValue, updateAvailableValue, systemInfo.Version, systemInfo.Update.AvailableVersion)
+	if err != nil {
+		return fmt.Errorf("error creating metric for %s: %w", systemUpdateAvailableDesc, err)
+	}
+	ch <- metric
+
+	return nil
+}
+
 func collectShares(ch chan<- prometheus.Metric, shares serverinfo.Shares) error {
 	values := make(map[string]float64)
 	values["user"] = float64(shares.SharesUser)
